Module api

Module api 

Modules

add_capability
delete_kittynode
delete_package
get_capabilities
get_config
get_container_logs
get_installed_packages
get_onboarding_completed
get_operational_state
get_package_config
get_package_runtime_state
get_packages
get_packages_runtime_state
get_server_url
get_system_info
init_kittynode
install_package
is_docker_running
remove_capability
resume_package
set_auto_start_docker
set_onboarding_completed
set_server_url
start_docker
start_docker_if_needed
stop_package
types
update_package_config

Enums

DockerStartStatus

Constants

DEFAULT_WEB_PORT

Functions

add_capability
Adds a capability to the config if it doesn’t already exist.
delete_kittynode
Deletes the Kittynode config directory
delete_package
get_capabilities
get_config
Returns the persisted Kittynode configuration
get_container_logs
get_installed_packages
get_onboarding_completed
get_operational_state
Returns the operational state describing runtime capabilities for the current mode.
get_package_config
get_package_runtime_state
get_packages
get_packages_runtime_state
get_server_url
get_system_info
get_web_service_log_path
get_web_service_status
init_kittynode
Initializes Kittynode, preserving onboarding state
install_package
is_docker_running
kittynode_cli_path
kittynode_path
remove_capability
resume_package
set_auto_start_docker
Enables or disables automatic Docker startup at application launch
set_onboarding_completed
set_server_url
start_docker
start_docker_if_needed
Attempts to start Docker if the configuration allows auto start and Docker is not already running.
start_web_service
stop_package
stop_web_service
update_package_config
validate_web_port