pub async fn get_operational_state() -> Result<OperationalState>Expand description
Returns the operational state describing runtime capabilities for the current mode.
pub async fn get_operational_state() -> Result<OperationalState>Returns the operational state describing runtime capabilities for the current mode.