pub async fn start_docker_if_needed() -> Result<DockerStartStatus>Expand description
Attempts to start Docker if the configuration allows auto start and Docker is not already running.
pub async fn start_docker_if_needed() -> Result<DockerStartStatus>Attempts to start Docker if the configuration allows auto start and Docker is not already running.